@@ -1,7 +1,7 @@
 package SQL::Translator::Schema::Table;
 
 # ----------------------------------------------------------------------
-# $Id: Table.pm,v 1.24 2004/02/09 22:15:15 kycl4rk Exp $
+# $Id: Table.pm,v 1.26 2004/03/29 12:25:54 grommit Exp $
 # ----------------------------------------------------------------------
 # Copyright (C) 2002-4 SQLFairy Authors
 #
@@ -51,7 +51,17 @@ use Data::Dumper;
 use base 'Class::Base';
 use vars qw( $VERSION $FIELD_ORDER );
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.24 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.26 $ =~ /(\d+)\.(\d+)/;
+
+
+# Stringify to our name, being careful not to pass any args through so we don't
+# accidentally set it to undef. We also have to tweak bool so the object is
+# still true when it doesn't have a name (which shouldn't happen!).
+use overload
+    '""'     => sub { shift->name },
+    'bool'   => sub { $_[0]->name || $_[0] },
+    fallback => 1,
+;
 
 # ----------------------------------------------------------------------
 sub init {
@@ -244,7 +254,8 @@ existing field, you will get an error and the field will not be created.
     }
 
     $field->order( ++$FIELD_ORDER );
-    my $field_name = $field->name or return $self->error('No name');
+    # We know we have a name as the Field->new above errors if none given.
+    my $field_name = $field->name;
 
     if ( exists $self->{'fields'}{ $field_name } ) { 
         return $self->error(qq[Can't create field: "$field_name" exists]);
@@ -424,7 +435,9 @@ sub is_trivial_link {
 
 =pod
 
-=head2 is_data
+=head2 is_trivial_link
+
+True if table has no data (non-key) fields and only uses single key joins.
 
 =cut
 
@@ -458,6 +471,8 @@ sub is_data {
 
 =head2 is_data
 
+Returns true if the table has some non-key fields.
+
 =cut
 
     my $self = shift;
@@ -576,8 +591,11 @@ sub name {
 
 Get or set the table's name.
 
-If provided an argument, checks the schema object for a table of 
-that name and disallows the change if one exists.
+Errors ("No table name") if you try to set a blank name.
+
+If provided an argument, checks the schema object for a table of
+that name and disallows the change if one exists (setting the error to
+"Can't use table name "%s": table exists").
 
   my $table_name = $table->name('foo');
 
@@ -585,7 +603,8 @@ that name and disallows the change if one exists.
 
     my $self = shift;
 
-    if ( my $arg = shift ) {
+    if ( @_ ) {
+        my $arg = shift || return $self->error( "No table name" );
         if ( my $schema = $self->schema ) {
             return $self->error( qq[Can't use table name "$arg": table exists] )
                 if $schema->get_table( $arg );
@@ -734,6 +753,128 @@ Get or set the table's order.
     return $self->{'order'} || 0;
 }
 
+# ----------------------------------------------------------------------
+sub field_names {
+
+=head2 field_names
+
+Read-only method to return a list or array ref of the field names. Returns undef
+or an empty list if the table has no fields set. Usefull if you want to
+avoid the overload magic of the Field objects returned by the get_fields method.
+
+  my @names = $constraint->field_names;
+
+=cut
+
+    my $self = shift;
+    my @fields = 
+        map  { $_->name }
+        sort { $a->order <=> $b->order }
+        values %{ $self->{'fields'} || {} };
+
+    if ( @fields ) {
+        return wantarray ? @fields : \@fields;
+    }
+    else {
+        $self->error('No fields');
+        return wantarray ? () : undef;
+    }
+}
+
+# ----------------------------------------------------------------------
+
+=head1 LOOKUP METHODS
+
+The following are a set of shortcut methods for getting commonly used lists of 
+fields and constraints. They all return lists or array refs of Field or 
+Constraint objects.
+
+=over 4
+
+=item pkey_fields
+
+The primary key fields.
+
+=item fkey_fields
+
+All foreign key fields.
+
+=item nonpkey_fields
+
+All the fields except the primary key.
+
+=item data_fields
+
+All non key fields.
+
+=item unique_fields
+
+All fields with unique constraints.
+
+=item unique_constraints
+
+All this tables unique constraints.
+
+=item fkey_constraints
+
+All this tables foreign key constraints. (See primary_key method to get the
+primary key constraint)
+
+=back
+
+=cut
+
+sub pkey_fields {
+    my $me = shift;
+    my @fields = grep { $_->is_primary_key } $me->get_fields;
+    return wantarray ? @fields : \@fields;
+}
+
+# ----------------------------------------------------------------------
+sub fkey_fields {
+    my $me = shift;
+    my @fields;
+    push @fields, $_->fields foreach $me->fkey_constraints;
+    return wantarray ? @fields : \@fields;
+}
+
+# ----------------------------------------------------------------------
+sub nonpkey_fields {
+    my $me = shift;
+    my @fields = grep { !$_->is_primary_key } $me->get_fields;
+    return wantarray ? @fields : \@fields;
+}
+
+# ----------------------------------------------------------------------
+sub data_fields {
+    my $me = shift;
+    my @fields =
+        grep { !$_->is_foreign_key and !$_->is_primary_key } $me->get_fields;
+    return wantarray ? @fields : \@fields;
+}
+
+# ----------------------------------------------------------------------
+sub unique_fields {
+    my $me = shift;
+    my @fields;
+    push @fields, $_->fields foreach $me->unique_constraints;
+    return wantarray ? @fields : \@fields;
+}
+
+# ----------------------------------------------------------------------
+sub unique_constraints {
+    my $me = shift;
+    my @cons = grep { $_->type eq UNIQUE } $me->get_constraints;
+    return wantarray ? @cons : \@cons;
+}
+
+# ----------------------------------------------------------------------
+sub fkey_constraints {
+    my $me = shift;
+    my @cons = grep { $_->type eq FOREIGN_KEY } $me->get_constraints;
+    return wantarray ? @cons : \@cons;
+}
+
 # ----------------------------------------------------------------------
 sub DESTROY {
     my $self = shift;
